/*
  PackageView - Show debian package details
  Copyright (C) 2008  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "Package.h"

#include <Lum/Image.h>
#include <Lum/Panel.h>
#include <Lum/Text.h>

#include "Globals.h"

Package::Package(Lum::Model::ListTable *table,
                 const std::wstring& name,
                 const std::wstring& version,
                 const std::wstring& section,
                 const std::wstring& shortDesc,
                 const std::wstring& longDesc,
                 const std::wstring& maintainer,
                 const std::wstring& homepage,
                 const std::wstring& dependencies,
                 size_t size,
                 size_t installedSize)
: Lum::Model::ListTable::Entry(table),
  name(name),
  version(version),
  section(section),
  shortDesc(shortDesc),
  longDesc(longDesc),
  maintainer(maintainer),
  homepage(homepage),
  dependencies(dependencies),
  size(size),
  installedSize(installedSize),
  nameObject(NULL)
{
  // no code
}

Package::~Package()
{
  delete nameObject;
}

Lum::Object* Package::GetObject(size_t column) const
{
  switch (column) {
  case 1:
    if (nameObject==NULL) {
      Lum::Panel *panel;
      Lum::Text  *text;

      panel=new Lum::VPanel();
      panel->SetFlex(true,true);

      text=new Lum::Text();
      text->SetFlex(true,false);
      text->AddText(name,Lum::OS::Font::bold);
      text->AddText(L" (");
      text->AddText(section,
                    Lum::OS::Font::normal,
                    Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
                                              Lum::OS::Display::fontScaleFootnote));
      text->AddText(L")");
      panel->Add(text);

      text=new Lum::Text(shortDesc,
                         Lum::OS::Font::italic,
                         Lum::Text::left,
                         Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
                                                   Lum::OS::Display::fontScaleFootnote));
      text->SetFlex(true,false);
      panel->Add(text);

      nameObject=panel;
    }
    return nameObject;
  default:
    return NULL;
  }
}


std::wstring Package::GetString(size_t column) const
{
  switch (column) {
  case 1:
    return L"";
  case 2:
    return version;
  default:
    assert(false);
  }
}

std::wstring Package::GetName() const
{
  return name;
}

std::wstring Package::GetVersion() const
{
  return version;
}

std::wstring Package::GetSection() const
{
  return section;
}

std::wstring Package::GetShortDescription() const
{
  return shortDesc;
}

std::wstring Package::GetDescription() const
{
  return longDesc;
}

std::wstring Package::GetMaintainer() const
{
  return maintainer;
}

std::wstring Package::GetHomepage() const
{
  return homepage;
}

std::wstring Package::GetDependencies() const
{
  return dependencies;
}

size_t Package::GetPackageSize() const
{
  return size;
}

size_t Package::GetInstalledSize() const
{
  return installedSize;
}

bool Package::IsGreater(const Entry* other, size_t column) const
{
  return name>dynamic_cast<const Package*>(other)->name;
}

